/*******************************************************************************
 *
 * blueMarine - open source photo workflow
 * =======================================
 *
 * Copyright (C) 2003-2010 by Fabrizio Giudici
 * Project home page: http://bluemarine.tidalwave.it
 *
 *******************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *******************************************************************************
 *
 * $Id: IdLazyLookup.java,v 1c263a6d8ac9 2010/02/14 00:23:33 fabrizio $
 *
 ******************************************************************************/
package it.tidalwave.openrdf.elmo.impl;

import javax.xml.namespace.QName;
import org.openrdf.elmo.Entity;
import it.tidalwave.util.Id;
import javax.annotation.Nonnull;

/*******************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id: IdLazyLookup.java,v 1c263a6d8ac9 2010/02/14 00:23:33 fabrizio $
 *
 ******************************************************************************/
public class IdLazyLookup extends EntityBasedLookup<Entity>
  {
    private Id id;

    /***************************************************************************
     *
     *
     **************************************************************************/
    public IdLazyLookup (@Nonnull final Entity entity)
      {
        super(entity);
      }

    /***************************************************************************
     *
     *
     **************************************************************************/
    @Override
    public synchronized <T> T lookup (Class<T> clazz)
      {
        if (!Id.class.equals(clazz))
          {
            return null;
          }

        if (id == null)
          {
            final QName qName = getQName();
            id = new Id(qName.getNamespaceURI() + qName.getLocalPart());
          }
        
        return (T)id;
      }

    /***************************************************************************
     *
     *
     **************************************************************************/
    @Override
    @Nonnull
    public String toString()
      {
        return String.format("IdLazyLookup@%x", System.identityHashCode(this));
      }
  }
